@@ -349,8 +349,8 @@ pub struct ItemStateAndInfo<'a> {
     pub oid: &'a OID,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub status: Option<ItemStatus>,
-    #[serde(default, skip_serializing_if = "ValueOptionOwned::is_none")]
-    pub value: ValueOptionOwned,
+    #[serde(default, skip_serializing_if = "ValueOption::is_none")]
+    pub value: ValueOption<'a>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub act: Option<usize>,
     pub ieid: Option<IEID>,
@@ -358,3 +358,47 @@ pub struct ItemStateAndInfo<'a> {
     pub node: &'a str,
     pub connected: bool,
 }
+
+/// full state with info, returned by item.state RPC functions, used in HMI and other apps
+#[derive(Debug, Serialize, Clone)]
+#[serde(deny_unknown_fields)]
+pub struct FullItemStateAndInfoOwned {
+    #[serde(flatten)]
+    pub si: ItemStateAndInfoOwned,
+    // full
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub meta: Option<Value>,
+    pub enabled: bool,
+}
+
+/// short state with info, returned by item.state RPC functions, used in HMI and other apps
+#[derive(Debug, Serialize, Clone)]
+#[serde(deny_unknown_fields)]
+pub struct ItemStateAndInfoOwned {
+    pub oid: OID,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub status: Option<ItemStatus>,
+    #[serde(default, skip_serializing_if = "ValueOptionOwned::is_none")]
+    pub value: ValueOptionOwned,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub act: Option<usize>,
+    pub ieid: Option<IEID>,
+    pub t: Option<f64>,
+    pub node: String,
+    pub connected: bool,
+}
+
+impl From<FullItemStateAndInfoOwned> for ReplicationInventoryItem {
+    fn from(s: FullItemStateAndInfoOwned) -> ReplicationInventoryItem {
+        ReplicationInventoryItem {
+            oid: s.si.oid,
+            status: s.si.status,
+            value: s.si.value,
+            act: s.si.act,
+            ieid: s.si.ieid,
+            t: s.si.t,
+            meta: s.meta,
+            enabled: s.enabled,
+        }
+    }
+}
